@@ -35,6 +35,7 @@ class OreDocumentationForm;
 class OreAboutForm;
 class OreGst;
 class OreDBus;
+class OreMJpegDialog;
 
 namespace Ui {
   class MainWindow;
@@ -110,6 +111,9 @@ private slots:
   void on_audioComboBox_currentIndexChanged(int index);
   void on_videoComboBox_currentIndexChanged(int index);
 
+  void startPlaying();
+  void stopPlaying();
+
 private:
   OrePreferencesForm *preferencesForm;
   OreVideoMonitorForm *videoMonitorForm;
@@ -118,6 +122,7 @@ private:
 
   OreGst *myGst;
   OreDBus *myDBus;
+  OreMJpegDialog *myUrlDialog;
 
 /*
   bool recordInput;
@@ -133,6 +138,8 @@ private:
   int elapsedTime;
   QTimer secondTimer;
 
+  QString filenameToPlay;
+
   Ui::MainWindow *ui;
 };
 
